#!/bin/bash
set -e
# Simple zip and xml import
dpbuddy import -file dpconfigs/WSProxy.zip
dpbuddy import -file dpconfigs/LoadBalancerGroup.xml
# Save domain configuration upon import's success
dpbuddy import -file dpconfigs/XMLFirewall.xml -save
# Create a checkpoint before importing the file, perform the import,
# validate that all services are up and running,
# rollback to the checkpoint on failure. For the objects that are in the "down" state,
# DPBuddy will pull and display log entries containing errors.
dpbuddy import -file dpconfigs/WSProxy.zip -checkpoint "before-import" -assertObjectsUp -rollbackOnError
# Quiesce the domain before importing the file, perform the import,
# validate that all services are up and running, un-quiesce the domain.
dpbuddy import -file dpconfigs/WSProxy.zip -quiesce -assertObjectsUp  -unquiesce
# Resolve template variables before the import, update domain comments after the import.
dpbuddy import -file dpconfigs/WSProxy.zip -resolveVars -domainComments "release-1.0.1"
# Export saved configuration of all proxies and firewalls
dpbuddy export -file services.zip -persisted -classPattern "(WSGatew.*|.*Firewall.*)"

